@@ -66,10 +66,13 @@ import typing_extensions
 
 from ._jsii import *
 
-__all__: typing.List[typing.Any] = []
+__all__ = [
+    "pdk_pipeline",
+    "pdk_projen",
+]
 
 publication.publish()
 
 # Loading modules to ensure their types are registered with the jsii runtime library
 from . import pdk_pipeline
-
+from . import pdk_projen
